@@ -49,13 +49,13 @@ void K3b::addDefaultPrograms( K3bExternalBinManager* m )
 void K3b::addTranscodePrograms( K3bExternalBinManager* m )
 {
   static const char* transcodeTools[] =  { "transcode",
-					   0, // K3b 1.0 only uses the transcode binary
-					   "tcprobe",
-					   "tccat",
-					   "tcscan",
-					   "tcextract",
-					   "tcdecode",
-					   0 };
+                                           0, // K3b 1.0 only uses the transcode binary
+                                           "tcprobe",
+                                           "tccat",
+                                           "tcscan",
+                                           "tcextract",
+                                           "tcdecode",
+                                           0 };
 
   for( int i = 0; transcodeTools[i]; ++i )
     m->addProgram( new K3bTranscodeProgram( transcodeTools[i] ) );
@@ -102,16 +102,16 @@ static TQString& debianWeirdnessHack( TQString& path )
       f.open( IO_ReadOnly );
       TQString s = TQTextStream( &f ).read();
       if( s.contains( "cdrecord.mmap" ) && s.contains( "cdrecord.shm" ) ) {
-	kdDebug() << "(K3bCdrecordProgram) Found Debian Wrapper script." << endl;
-	TQString ext;
-	if( K3b::kernelVersion().versionString().left(3) > "2.2" )
-	  ext = ".mmap";
-	else
-	  ext = ".shm";
+        kdDebug() << "(K3bCdrecordProgram) Found Debian Wrapper script." << endl;
+        TQString ext;
+        if( K3b::kernelVersion().versionString().left(3) > "2.2" )
+          ext = ".mmap";
+        else
+          ext = ".shm";
 
-	kdDebug() << "(K3bCdrecordProgram) Using cdrecord" << ext << endl;
+        kdDebug() << "(K3bCdrecordProgram) Using cdrecord" << ext << endl;
 
-	path += ext;
+        path += ext;
       }
     }
   }
@@ -214,7 +214,7 @@ bool K3bCdrecordProgram::scan( const TQString& p )
     if( out.output().contains( "-tao" ) )
       bin->addFeature( "tao" );
     if( out.output().contains( "cuefile=" ) &&
-	( wodim || bin->version > K3bVersion( 2, 1, -1, "a14") ) ) // cuefile handling was still buggy in a14
+        ( wodim || bin->version > K3bVersion( 2, 1, -1, "a14") ) ) // cuefile handling was still buggy in a14
       bin->addFeature( "cuefile" );
 
     // new mode 2 options since cdrecord 2.01a12
@@ -223,15 +223,15 @@ bool K3bCdrecordProgram::scan( const TQString& p )
     // two checks)
     // and the version check does not handle versions like 2.01-dvd properly
     if( out.output().contains( "-xamix" ) ||
-	bin->version >= K3bVersion( 2, 1, -1, "a12" ) ||
-	wodim )
+        bin->version >= K3bVersion( 2, 1, -1, "a12" ) ||
+        wodim )
       bin->addFeature( "xamix" );
 
     // check if we run cdrecord as root
     struct stat s;
     if( !::stat( TQFile::encodeName(path), &s ) ) {
       if( (s.st_mode & S_ISUID) && s.st_uid == 0 )
-	bin->addFeature( "suidroot" );
+        bin->addFeature( "suidroot" );
     }
   }
   else {
@@ -352,7 +352,7 @@ bool K3bMkisofsProgram::scan( const TQString& p )
     struct stat s;
     if( !::stat( TQFile::encodeName(path), &s ) ) {
       if( (s.st_mode & S_ISUID) && s.st_uid == 0 )
-	bin->addFeature( "suidroot" );
+        bin->addFeature( "suidroot" );
     }
   }
   else {
@@ -458,7 +458,7 @@ bool K3bReadcdProgram::scan( const TQString& p )
     struct stat s;
     if( !::stat( TQFile::encodeName(path), &s ) ) {
       if( (s.st_mode & S_ISUID) && s.st_uid == 0 )
-	bin->addFeature( "suidroot" );
+        bin->addFeature( "suidroot" );
     }
   }
   else {
@@ -551,7 +551,7 @@ bool K3bCdrdaoProgram::scan( const TQString& p )
     struct stat s;
     if( !::stat( TQFile::encodeName(path), &s ) ) {
       if( (s.st_mode & S_ISUID) && s.st_uid == 0 )
-	bin->addFeature( "suidroot" );
+        bin->addFeature( "suidroot" );
     }
   }
   else {
@@ -712,20 +712,41 @@ K3bNormalizeProgram::K3bNormalizeProgram()
 {
 }
 
+TQStringList K3bNormalizeProgram::binNames() const {
+  TQStringList rv;
+  rv << "normalize-audio" << "normalize";
+  return rv;
+}
 
 bool K3bNormalizeProgram::scan( const TQString& p )
 {
   if( p.isEmpty() )
     return false;
 
-  TQString path = p;
-  TQFileInfo fi( path );
+  bool found = false;
+
+  TQFileInfo fi( p );
   if( fi.isDir() ) {
-    if( path[path.length()-1] != '/' )
-      path.append("/");
-    path.append("normalize-audio");
+
+    for(const auto & name: binNames()) {
+      TQString path = p;
+      if( path[path.length()-1] != '/' )
+        path.append("/");
+      path.append(name);
+
+      if( verifyAddBin(path) )
+        found = true;
+    }
+  } else {
+    if( verifyAddBin(p) )
+      found = true;
   }
 
+  return found;
+}
+
+
+bool K3bNormalizeProgram::verifyAddBin( const TQString& path ) {
   if( !TQFile::exists( path ) )
     return false;
 
