@@ -27,7 +27,7 @@ class TDEProcess;
  */
 class LIBK3B_EXPORT K3bVideoDVDTitleDetectClippingJob : public K3bJob
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
