@@ -80,7 +80,7 @@ void K3bPushButton::setDelayedPopupMenu( TQPopupMenu* popup )
 {
   if( !d->popupTimer ) {
     d->popupTimer = new TQTimer( this );
-    connect( d->popupTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotDelayedPopup()) );
+    connect( d->popupTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotDelayedPopup()) );
   }
 
   setPopup( popup );
@@ -99,12 +99,12 @@ bool K3bPushButton::eventFilter( TQObject* o, TQEvent* ev )
     // is moved by a small distance.
     if( popup() ) {
       if( ev->type() == TQEvent::MouseButtonPress ) {
-        TQMouseEvent* mev = TQT_TQMOUSEEVENT(ev);
+        TQMouseEvent* mev = static_cast<TQMouseEvent*>(ev);
         d->mousePressPos = mev->pos();
 	d->popupTimer->start( TQApplication::startDragTime() );
       }
       else if( ev->type() == TQEvent::MouseMove ) {
-        TQMouseEvent* mev = TQT_TQMOUSEEVENT(ev);
+        TQMouseEvent* mev = static_cast<TQMouseEvent*>(ev);
         if( ( mev->pos() - d->mousePressPos).manhattanLength() > TDEGlobalSettings::dndEventDelay() ) {
 	  d->popupTimer->stop();
 	  slotDelayedPopup();
