@@ -26,7 +26,7 @@
 
 class K3bExternalEncoderEditDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   
  public:
@@ -46,7 +46,7 @@ class K3bExternalEncoderEditDialog : public KDialogBase
 
 class K3bExternalEncoderSettingsWidget : public K3bPluginConfigWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
