@@ -26,7 +26,7 @@
 #include <k3bpluginfactory.h>
 
 #include <kdebug.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdemessagebox.h>
 #include <tdelocale.h>
 #include <tdefilemetainfo.h>
