@@ -29,7 +29,7 @@
 
 #include <k3bcore.h>
 #include <k3bdevicemanager.h>
-#include <k3bhalconnection.h>
+#include <k3bconnection.h>
 #include <k3bexternalbinmanager.h>
 #include <k3bdefaultexternalprograms.h>
 #include <k3bglobals.h>
@@ -72,16 +72,16 @@ K3bApplication::K3bApplication()
   TDEGlobal::locale()->insertCatalogue( "libk3bdevice" );
   TDEGlobal::locale()->insertCatalogue( "libk3b" );
 
-  m_core = new Core( TQT_TQOBJECT(this) );
+  m_core = new Core( this );
 
   // TODO: move to K3bCore?
   // from this point on available through K3bAudioServer::instance()
-  m_audioServer = new K3bAudioServer( TQT_TQOBJECT(this), "K3bAudioServer" );
+  m_audioServer = new K3bAudioServer( this, "K3bAudioServer" );
 
-  connect( m_core, TQT_SIGNAL(initializationInfo(const TQString&)),
-	   TQT_SIGNAL(initializationInfo(const TQString&)) );
+  connect( m_core, TQ_SIGNAL(initializationInfo(const TQString&)),
+	   TQ_SIGNAL(initializationInfo(const TQString&)) );
 
-  connect( this, TQT_SIGNAL(shutDown()), TQT_SLOT(slotShutDown()) );
+  connect( this, TQ_SIGNAL(shutDown()), TQ_SLOT(slotShutDown()) );
 }
 
 
@@ -104,10 +104,10 @@ void K3bApplication::init()
       m_core->m_themeManager->readConfig( config() );
 
       splash = new K3bSplash( 0 );
-      splash->connect( this, TQT_SIGNAL(initializationInfo(const TQString&)), TQT_SLOT(addInfo(const TQString&)) );
+      splash->connect( this, TQ_SIGNAL(initializationInfo(const TQString&)), TQ_SLOT(addInfo(const TQString&)) );
 
       // kill the splash after 5 seconds
-      TQTimer::singleShot( 5000, splash, TQT_SLOT(close()) );
+      TQTimer::singleShot( 5000, splash, TQ_SLOT(close()) );
 
       splash->show();
       tqApp->processEvents();
@@ -382,8 +382,8 @@ void K3bApplication::Core::init()
 
   mediaCache()->buildDeviceList( deviceManager() );
 
-  connect( deviceManager(), TQT_SIGNAL(changed(K3bDevice::DeviceManager*)),
-           mediaCache(), TQT_SLOT(buildDeviceList(K3bDevice::DeviceManager*)) );
+  connect( deviceManager(), TQ_SIGNAL(changed(K3bDevice::DeviceManager*)),
+           mediaCache(), TQ_SLOT(buildDeviceList(K3bDevice::DeviceManager*)) );
 }
 
 
@@ -416,8 +416,8 @@ bool K3bApplication::Core::internalBlockDevice( K3bDevice::Device* dev )
       m_deviceBlockMap[dev] = mediaCache()->blockDevice( dev );
     }
 
-    if( K3bDevice::HalConnection::instance()->lock( dev ) != K3bDevice::HalConnection::org_freedesktop_Hal_Success )
-      kdDebug() << "(K3bInterferingSystemsHandler) HAL lock failed." << endl;
+    if( K3bDevice::Connection::instance()->lock( dev ) != K3bDevice::Connection::ErrorCodes::Success )
+      kdDebug() << "(K3bInterferingSystemsHandler) lock failed." << endl;
 
     //
     // Check if the device is in use
@@ -439,7 +439,7 @@ void K3bApplication::Core::internalUnblockDevice( K3bDevice::Device* dev )
     m_deviceBlockMap.erase( dev );
   }
 
-  K3bDevice::HalConnection::instance()->unlock( dev );
+  K3bDevice::Connection::instance()->unlock( dev );
 
   K3bCore::internalUnblockDevice( dev );
 }
