@@ -29,7 +29,7 @@ class TQLabel;
   */
 class K3bBurnProgressDialog : public K3bJobProgressDialog  {
 
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
