@@ -21,7 +21,7 @@
 
 class K3bFirstRun : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
