@@ -96,9 +96,9 @@ K3bWelcomeWidget::Display::Display( K3bWelcomeWidget* parent )
   m_rows = m_cols = 1;
 
   m_buttonMore = new K3bFlatButton( i18n("Further actions..."), this );
-  connect( m_buttonMore, TQT_SIGNAL(pressed()), parent, TQT_SLOT(slotMoreActions()) );
+  connect( m_buttonMore, TQ_SIGNAL(pressed()), parent, TQ_SLOT(slotMoreActions()) );
 
-  connect( k3bappcore->themeManager(), TQT_SIGNAL(themeChanged()), this, TQT_SLOT(slotThemeChanged()) );
+  connect( k3bappcore->themeManager(), TQ_SIGNAL(themeChanged()), this, TQ_SLOT(slotThemeChanged()) );
 
   slotThemeChanged();
 }
@@ -351,9 +351,9 @@ K3bWelcomeWidget::K3bWelcomeWidget( K3bMainWindow* mw, TQWidget* parent, const c
   main = new Display( this );
   addChild( main );
 
-  connect( main, TQT_SIGNAL(dropped(const KURL::List&)), m_mainWindow, TQT_SLOT(addUrls(const KURL::List&)) );
+  connect( main, TQ_SIGNAL(dropped(const KURL::List&)), m_mainWindow, TQ_SLOT(addUrls(const KURL::List&)) );
 
-  connect( kapp, TQT_SIGNAL(appearanceChanged()), main, TQT_SLOT(update()) );
+  connect( kapp, TQ_SIGNAL(appearanceChanged()), main, TQ_SLOT(update()) );
 }
 
 
@@ -425,7 +425,7 @@ void K3bWelcomeWidget::fixSize()
 
 void K3bWelcomeWidget::contentsMousePressEvent( TQMouseEvent* e )
 {
-  if( e->button() == Qt::RightButton ) {
+  if( e->button() == TQt::RightButton ) {
     TQMap<int, TDEAction*> map;
     TDEPopupMenu addPop;
 
@@ -438,7 +438,7 @@ void K3bWelcomeWidget::contentsMousePressEvent( TQMouseEvent* e )
         }
     }
 
-    // menu identifiers in QT are always < 0 (when automatically generated)
+    // menu identifiers in TQt are always < 0 (when automatically generated)
     // and unique throughout the entire application!
     int r = 0;
     int removeAction = 0;
@@ -476,7 +476,7 @@ void K3bWelcomeWidget::slotMoreActions()
 
   for ( int i = 0; s_allActions[i]; ++i ) {
       if ( s_allActions[i][0] == '_' ) {
-          (new TDEActionSeparator( TQT_TQOBJECT(&popup) ))->plug( &popup );
+          (new TDEActionSeparator( &popup ))->plug( &popup );
       }
       else {
           m_mainWindow->actionCollection()->action( s_allActions[i] )->plug( &popup );
