@@ -58,14 +58,14 @@ K3bDvdFormattingDialog::K3bDvdFormattingDialog( TQWidget* parent, const char* na
   m_writerSelectionWidget->setSupportedWritingApps( K3b::DVD_RW_FORMAT );
   m_writerSelectionWidget->setForceAutoSpeed(true);
 
-  TQGroupBox* groupWritingMode = new TQGroupBox( 1, Qt::Vertical, i18n("Writing Mode"), frame );
+  TQGroupBox* groupWritingMode = new TQGroupBox( 1, TQt::Vertical, i18n("Writing Mode"), frame );
   groupWritingMode->layout()->setMargin( marginHint() );
   groupWritingMode->layout()->setSpacing( spacingHint() );
   m_writingModeWidget = new K3bWritingModeWidget( K3b::WRITING_MODE_INCR_SEQ|K3b::WRITING_MODE_RES_OVWR,
 						  groupWritingMode );
 
 
-  TQGroupBox* groupOptions = new TQGroupBox( 2, Qt::Vertical, i18n("Settings"), frame );
+  TQGroupBox* groupOptions = new TQGroupBox( 2, TQt::Vertical, i18n("Settings"), frame );
   groupOptions->layout()->setMargin( marginHint() );
   groupOptions->layout()->setSpacing( spacingHint() );
   m_checkForce = new TQCheckBox( i18n("Force"), groupOptions );
@@ -99,9 +99,9 @@ K3bDvdFormattingDialog::K3bDvdFormattingDialog( TQWidget* parent, const char* na
 					    "time and some DVD writers perform a full format even if "
 					    "quick format is enabled." ) );
 
-  connect( m_writerSelectionWidget, TQT_SIGNAL(writerChanged()), this, TQT_SLOT(slotWriterChanged()) );
-  connect( m_writerSelectionWidget, TQT_SIGNAL(writerChanged(K3bDevice::Device*)),
-	   m_writingModeWidget, TQT_SLOT(determineSupportedModesFromMedium(K3bDevice::Device*)) );
+  connect( m_writerSelectionWidget, TQ_SIGNAL(writerChanged()), this, TQ_SLOT(slotWriterChanged()) );
+  connect( m_writerSelectionWidget, TQ_SIGNAL(writerChanged(K3bDevice::Device*)),
+	   m_writingModeWidget, TQ_SLOT(determineSupportedModesFromMedium(K3bDevice::Device*)) );
 
   slotWriterChanged();
 } 
@@ -128,7 +128,7 @@ void K3bDvdFormattingDialog::slotStartClicked()
 
   K3bJobProgressDialog d( kapp->mainWidget(), "formattingProgress", false );
 
-  K3bDvdFormattingJob*  job = new K3bDvdFormattingJob( &d, TQT_TQOBJECT(this) );
+  K3bDvdFormattingJob*  job = new K3bDvdFormattingJob( &d, this );
   job->setDevice( m_writerSelectionWidget->writerDevice() );
   job->setMode( m_writingModeWidget->writingMode() );
   job->setForce( m_checkForce->isChecked() );
