@@ -91,9 +91,9 @@ K3bDataUrlAddingDialog::K3bDataUrlAddingDialog( K3bDataDoc* doc, TQWidget* paren
   grid->addWidget( m_infoLabel, 0, 0 );
   grid->addMultiCellWidget( m_progressWidget, 1, 1, 0, 1 );
 
-  m_dirSizeJob = new K3bDirSizeJob( TQT_TQOBJECT(this) );
-  connect( m_dirSizeJob, TQT_SIGNAL(finished(bool)),
-	   this, TQT_SLOT(slotDirSizeDone(bool)) );
+  m_dirSizeJob = new K3bDirSizeJob( this );
+  connect( m_dirSizeJob, TQ_SIGNAL(finished(bool)),
+	   this, TQ_SLOT(slotDirSizeDone(bool)) );
 
   // try to start with a reasonable size
   resize( (int)( fontMetrics().width( caption() ) * 1.5 ), sizeHint().height() );
@@ -141,7 +141,7 @@ int K3bDataUrlAddingDialog::addUrls( const KURL::List& urls,
   K3bDataUrlAddingDialog dlg( dir->doc(), parent );
   dlg.m_urls = urls;
   for( KURL::List::ConstIterator it = urls.begin(); it != urls.end(); ++it )
-    dlg.m_urlQueue.append( tqMakePair( K3b::convertToLocalUrl(*it), dir ) );
+    dlg.m_urlQueue.append( qMakePair( K3b::convertToLocalUrl(*it), dir ) );
 
   dlg.slotAddUrls();
   int ret = TQDialog::Accepted;
@@ -226,7 +226,7 @@ int K3bDataUrlAddingDialog::copyMoveItems( const TQValueList<K3bDataItem*>& item
   dlg.m_copyItems = copy;
 
   for( TQValueList<K3bDataItem*>::const_iterator it = items.begin(); it != items.end(); ++it ) {
-    dlg.m_items.append( tqMakePair( *it, dir ) );
+    dlg.m_items.append( qMakePair( *it, dir ) );
     ++dlg.m_totalFiles;
     if( (*it)->isDir() ) {
       dlg.m_totalFiles += static_cast<K3bDirItem*>( *it )->numFiles();
@@ -568,7 +568,7 @@ void K3bDataUrlAddingDialog::slotAddUrls()
       dlist.remove( dotdot );
 
       for( TQStringList::Iterator it = dlist.begin(); it != dlist.end(); ++it ) {
-	m_urlQueue.append( tqMakePair( KURL::fromPathOrURL(absFilePath + '/' + *it), newDirItem ) );
+	m_urlQueue.append( qMakePair( KURL::fromPathOrURL(absFilePath + '/' + *it), newDirItem ) );
       }
     }
     else {
@@ -583,7 +583,7 @@ void K3bDataUrlAddingDialog::slotAddUrls()
   }
   else {
     updateProgress();
-    TQTimer::singleShot( 0, this, TQT_SLOT(slotAddUrls()) );
+    TQTimer::singleShot( 0, this, TQ_SLOT(slotAddUrls()) );
   }
 }
 
@@ -625,7 +625,7 @@ void K3bDataUrlAddingDialog::slotCopyMoveItems()
       if( oldItem->isDir() && item->isDir() ) {
 	const TQPtrList<K3bDataItem>& cl = dynamic_cast<K3bDirItem*>( item )->children();
 	for( TQPtrListIterator<K3bDataItem> it( cl ); *it; ++it )
-	  m_items.append( tqMakePair( *it, dynamic_cast<K3bDirItem*>( oldItem ) ) );
+	  m_items.append( qMakePair( *it, dynamic_cast<K3bDirItem*>( oldItem ) ) );
 
 	// FIXME: we need to remove the old dir item
       }
@@ -736,7 +736,7 @@ void K3bDataUrlAddingDialog::slotCopyMoveItems()
   }
   else {
     updateProgress();
-    TQTimer::singleShot( 0, this, TQT_SLOT(slotCopyMoveItems()) );
+    TQTimer::singleShot( 0, this, TQ_SLOT(slotCopyMoveItems()) );
   }
 }
 
@@ -745,7 +745,7 @@ bool K3bDataUrlAddingDialog::getNewName( const TQString& oldName, K3bDirItem* di
 {
   bool ok = true;
   newName = oldName;
-  TQValidator* validator = K3bValidators::iso9660Validator( false, TQT_TQOBJECT(this) );
+  TQValidator* validator = K3bValidators::iso9660Validator( false, this );
   do {
     newName = KInputDialog::getText( i18n("Enter New Filename"),
 				     i18n("A file with that name already exists. Please enter a new name:"),
