@@ -27,12 +27,12 @@
 #include <tqtoolbutton.h>
 #include <tqfileinfo.h>
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <kio/global.h>
-#include <kapplication.h>
+#include <tdeio/global.h>
+#include <tdeapplication.h>
 
 #include "k3bvcdburndialog.h"
 #include "k3bvcddoc.h"
@@ -69,7 +69,7 @@ K3bVcdBurnDialog::K3bVcdBurnDialog( K3bVcdDoc* _doc, TQWidget *parent, const cha
     }
 
     setTitle( vcdType, i18n( "1 MPEG (%1)", "%n MPEGs (%1)",
-                             m_vcdDoc->tracks() ->count() ).arg( KIO::convertSize( m_vcdDoc->size() ) ) );
+                             m_vcdDoc->tracks() ->count() ).arg( TDEIO::convertSize( m_vcdDoc->size() ) ) );
 
     const K3bExternalBin* cdrecordBin = k3bcore->externalBinManager() ->binObject( "cdrecord" );
     if ( cdrecordBin && cdrecordBin->hasFeature( "cuefile" ) )
@@ -86,11 +86,11 @@ K3bVcdBurnDialog::K3bVcdBurnDialog( K3bVcdDoc* _doc, TQWidget *parent, const cha
     setupLabelTab();
     setupAdvancedTab();
 
-    connect( m_spinVolumeCount, TQT_SIGNAL( valueChanged( int ) ), this, TQT_SLOT( slotSpinVolumeCount() ) );
-    connect( m_groupVcdFormat, TQT_SIGNAL( clicked( int ) ), this, TQT_SLOT( slotVcdTypeClicked( int ) ) );
-    connect( m_checkCdiSupport, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotCdiSupportChecked( bool ) ) );
-    connect( m_checkAutoDetect, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotAutoDetect( bool ) ) );
-    connect( m_checkGaps, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotGapsChecked( bool ) ) );
+    connect( m_spinVolumeCount, TQ_SIGNAL( valueChanged( int ) ), this, TQ_SLOT( slotSpinVolumeCount() ) );
+    connect( m_groupVcdFormat, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( slotVcdTypeClicked( int ) ) );
+    connect( m_checkCdiSupport, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotCdiSupportChecked( bool ) ) );
+    connect( m_checkAutoDetect, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotAutoDetect( bool ) ) );
+    connect( m_checkGaps, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotGapsChecked( bool ) ) );
 
     // ToolTips
     // -------------------------------------------------------------------------
@@ -296,7 +296,7 @@ void K3bVcdBurnDialog::setupAdvancedTab()
     TQWidget * w = new TQWidget( this );
 
     // ---------------------------------------------------- generic group ----
-    m_groupGeneric = new TQGroupBox( 5, Qt::Vertical, i18n( "Generic" ), w );
+    m_groupGeneric = new TQGroupBox( 5, TQt::Vertical, i18n( "Generic" ), w );
 
     m_checkPbc = new TQCheckBox( i18n( "Playback Control (PBC)" ), m_groupGeneric );
     m_checkSegmentFolder = new TQCheckBox( i18n( "SEGMENT Folder must always be present" ), m_groupGeneric );
@@ -306,7 +306,7 @@ void K3bVcdBurnDialog::setupAdvancedTab()
 
 
     // -------------------------------------------- gaps & margins group ----
-    m_groupGaps = new TQGroupBox( 0, Qt::Vertical, i18n( "Gaps" ), w );
+    m_groupGaps = new TQGroupBox( 0, TQt::Vertical, i18n( "Gaps" ), w );
     m_groupGaps->layout() ->setSpacing( spacingHint() );
     m_groupGaps->layout() ->setMargin( marginHint() );
 
@@ -402,7 +402,7 @@ void K3bVcdBurnDialog::setupAdvancedTab()
     groupGapsLayout->setRowStretch( 4, 0 );
 
     // ------------------------------------------------------- misc group ----
-    m_groupMisc = new TQGroupBox( 0, Qt::Vertical, i18n( "Misc" ), w );
+    m_groupMisc = new TQGroupBox( 0, TQt::Vertical, i18n( "Misc" ), w );
     m_groupMisc->layout() ->setSpacing( spacingHint() );
     m_groupMisc->layout() ->setMargin( marginHint() );
 
@@ -434,7 +434,7 @@ void K3bVcdBurnDialog::setupVideoCdTab()
     TQWidget * w = new TQWidget( this );
 
     // ---------------------------------------------------- Format group ----
-    m_groupVcdFormat = new TQButtonGroup( 4, Qt::Vertical, i18n( "Type" ), w );
+    m_groupVcdFormat = new TQButtonGroup( 4, TQt::Vertical, i18n( "Type" ), w );
     m_radioVcd11 = new TQRadioButton( i18n( "VideoCD 1.1" ), m_groupVcdFormat );
     m_radioVcd20 = new TQRadioButton( i18n( "VideoCD 2.0" ), m_groupVcdFormat );
     m_radioSvcd10 = new TQRadioButton( i18n( "Super-VideoCD" ), m_groupVcdFormat );
@@ -443,7 +443,7 @@ void K3bVcdBurnDialog::setupVideoCdTab()
 
     // ---------------------------------------------------- Options group ---
 
-    m_groupOptions = new TQGroupBox( 5, Qt::Vertical, i18n( "Settings" ), w );
+    m_groupOptions = new TQGroupBox( 5, TQt::Vertical, i18n( "Settings" ), w );
     m_checkAutoDetect = new TQCheckBox( i18n( "Autodetect VideoCD type" ), m_groupOptions );
 
     m_checkNonCompliant = new TQCheckBox( i18n( "Enable broken SVCD mode" ), m_groupOptions );
@@ -461,7 +461,7 @@ void K3bVcdBurnDialog::setupVideoCdTab()
     m_checkCdiSupport = new TQCheckBox( i18n( "Enable CD-i support" ), m_groupOptions );
 
     // ------------------------------------------------- CD-i Application ---
-    m_groupCdi = new TQGroupBox( 4, Qt::Vertical, i18n( "VideoCD on CD-i" ), w );
+    m_groupCdi = new TQGroupBox( 4, TQt::Vertical, i18n( "VideoCD on CD-i" ), w );
     m_editCdiCfg = new TQMultiLineEdit( m_groupCdi, "m_editCdiCfg" );
     m_editCdiCfg->setFrameShape( TQTextEdit::NoFrame );
 
@@ -511,13 +511,13 @@ void K3bVcdBurnDialog::setupLabelTab()
     m_editPublisher = new TQLineEdit( w, "m_editPublisher" );
 
     // only ISO646 d-Characters
-    m_editVolumeId->setValidator( K3bValidators::iso646Validator( K3bValidators::Iso646_d, true, TQT_TQOBJECT(m_editVolumeId) ) );
-    m_editAlbumId->setValidator( K3bValidators::iso646Validator( K3bValidators::Iso646_d, true, TQT_TQOBJECT(m_editVolumeId) ) );
+    m_editVolumeId->setValidator( K3bValidators::iso646Validator( K3bValidators::Iso646_d, true, m_editVolumeId ) );
+    m_editAlbumId->setValidator( K3bValidators::iso646Validator( K3bValidators::Iso646_d, true, m_editVolumeId ) );
 
     m_editVolumeId->setMaxLength( 32 );
     m_editAlbumId->setMaxLength( 16 );
     // only ISO646 a-Characters
-    m_editPublisher->setValidator( K3bValidators::iso646Validator( K3bValidators::Iso646_a, true, TQT_TQOBJECT(m_editVolumeId) ) );
+    m_editPublisher->setValidator( K3bValidators::iso646Validator( K3bValidators::Iso646_a, true, m_editVolumeId ) );
     m_editPublisher->setMaxLength( 128 );
 
     m_spinVolumeNumber->setMinValue( 1 );
@@ -619,7 +619,7 @@ void K3bVcdBurnDialog::loadK3bDefaults()
         m_checkCdiSupport->setEnabled( false );
         m_checkCdiSupport->setChecked( false );
         m_checkUpdateScanOffsets->setEnabled( true );
-        m_editVolumeId->setText( "HTQ_VIDEOCD" );
+        m_editVolumeId->setText( "HQ_VIDEOCD" );
     } else {
         m_checkCdiSupport->setEnabled( true );
         m_checkCdiSupport->setChecked( o.CdiSupport() );
@@ -793,7 +793,7 @@ void K3bVcdBurnDialog::readSettings()
     loadCdiConfig();
 }
 
-void K3bVcdBurnDialog::loadUserDefaults( KConfigBase* c )
+void K3bVcdBurnDialog::loadUserDefaults( TDEConfigBase* c )
 {
     K3bProjectBurnDialog::loadUserDefaults( c );
 
@@ -845,7 +845,7 @@ void K3bVcdBurnDialog::loadUserDefaults( KConfigBase* c )
 }
 
 
-void K3bVcdBurnDialog::saveUserDefaults( KConfigBase* c )
+void K3bVcdBurnDialog::saveUserDefaults( TDEConfigBase* c )
 {
     K3bProjectBurnDialog::saveUserDefaults( c );
 
@@ -959,7 +959,7 @@ void K3bVcdBurnDialog::setVolumeID()
         if ( m_radioSvcd10->isChecked() )
             m_editVolumeId->setText( "SUPER_VIDEOCD" );
         else if ( m_radioHqVcd10->isChecked() )
-            m_editVolumeId->setText( "HTQ_VIDEOCD" );
+            m_editVolumeId->setText( "HQ_VIDEOCD" );
         else
             m_editVolumeId->setText( "VIDEOCD" );
     }
