@@ -25,9 +25,9 @@
 #include <tqiodevice.h>
 #include <tqvaluestack.h>
 //#include <koffice_export.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
-#define KOSTORE_EXPORT KDE_EXPORT
+#define KOSTORE_EXPORT TDE_EXPORT
 
 class TQWidget;
 
