@@ -23,7 +23,7 @@
 #include <tdemessagebox.h>
 #include <kstandarddirs.h>
 
-// qt includes
+// TQt includes
 #include <tqgroupbox.h>
 #include <tqcheckbox.h>
 #include <tqlabel.h>
@@ -72,7 +72,7 @@ void K3bVideoCdRippingDialog::setupGui()
     MainLayout->setMargin( 0 );
 
     // ---------------------------------------------------- Directory group ---
-    TQGroupBox* groupDirectory = new TQGroupBox( 0, Qt::Vertical, i18n( "Destination Directory" ), frame );
+    TQGroupBox* groupDirectory = new TQGroupBox( 0, TQt::Vertical, i18n( "Destination Directory" ), frame );
     groupDirectory->layout() ->setSpacing( KDialog::spacingHint() );
     groupDirectory->layout() ->setMargin( KDialog::marginHint() );
 
@@ -105,7 +105,7 @@ void K3bVideoCdRippingDialog::setupGui()
     groupDirectoryLayout->addWidget( necessarySizeBox, 2, 1 );
 
     // ---------------------------------------------------- Options group ---
-    TQGroupBox* groupOptions = new TQGroupBox( 4, Qt::Vertical, i18n( "Settings" ), frame );
+    TQGroupBox* groupOptions = new TQGroupBox( 4, TQt::Vertical, i18n( "Settings" ), frame );
 
     m_ignoreExt = new TQCheckBox( i18n( "Ignore /EXT/PSD_X.VCD" ), groupOptions );
 
@@ -124,7 +124,7 @@ void K3bVideoCdRippingDialog::setupGui()
     setStartButtonText( i18n( "Start Ripping" ), i18n( "Starts extracting the selected VideoCd tracks" ) );
     // ----------------------------------------------------------------------------------
 
-    connect( m_editDirectory, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateFreeSpace()) );
+    connect( m_editDirectory, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateFreeSpace()) );
 
     m_labelNecessarySize ->setText( TDEIO::convertSize( m_videooptions ->getVideoCdSize() ) );    
 }
@@ -211,7 +211,7 @@ void K3bVideoCdRippingDialog::slotFreeSpace(const TQString&,
     else
         m_labelNecessarySize->setPaletteForegroundColor( m_labelFreeSpace->paletteForegroundColor() );
 
-    TQTimer::singleShot( 1000, this, TQT_SLOT(slotUpdateFreeSpace()) );
+    TQTimer::singleShot( 1000, this, TQ_SLOT(slotUpdateFreeSpace()) );
 }
 
 
